@@ -1,4 +1,3 @@
-/* $Xorg: Font.c,v 1.4 2001/02/09 02:03:33 xorgcvs Exp $ */
 /*
 
 Copyright 1986, 1998  The Open Group
@@ -27,9 +26,7 @@ sale, use or other dealings in this Software without prior written
 authorization from the X Consortium and the XFree86 Project.
 
 */
-/* $XFree86: xc/lib/X11/Font.c,v 1.17 2003/04/13 19:22:16 dawes Exp $ */
 
-#define NEED_REPLIES
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -47,7 +44,7 @@ authorization from the X Consortium and the XFree86 Project.
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <X11/extensions/xf86bigfstr.h>
+#include <X11/extensions/xf86bigfproto.h>
 #endif
 
 #include "Xlcint.h"
@@ -153,7 +150,7 @@ int
 XFreeFont(
     register Display *dpy,
     XFontStruct *fs)
-{ 
+{
     register xResourceReq *req;
     register _XExtension *ext;
 
@@ -230,7 +227,7 @@ _XQueryFont (
     fs->all_chars_exist 	= reply.allCharsExist;
     fs->ascent 			= cvtINT16toInt (reply.fontAscent);
     fs->descent 		= cvtINT16toInt (reply.fontDescent);
-    
+
 #ifdef MUSTCOPY
     {
 	xCharInfo *xcip;
@@ -258,7 +255,7 @@ _XQueryFont (
 #endif /* MUSTCOPY */
 
     fs->n_properties = reply.nFontProps;
-    /* 
+    /*
      * if no properties defined for the font, then it is bad
      * font, but shouldn't try to read nothing.
      */
@@ -290,7 +287,7 @@ _XQueryFont (
 			    (reply.nCharInfos * SIZEOF(xCharInfo)));
 	    return (XFontStruct *)NULL;
 	}
-	    
+
 #ifdef MUSTCOPY
 	{
 	    register XCharStruct *cs = fs->per_char;
@@ -516,7 +513,7 @@ _XF86BigfontQueryFont (
     fs->max_bounds = * (XCharStruct *) &reply.maxBounds;
 
     fs->n_properties = reply.nFontProps;
-    /* 
+    /*
      * if no properties defined for the font, then it is bad
      * font, but shouldn't try to read nothing.
      */
