@@ -1,4 +1,3 @@
-/* $Xorg: lcFile.c,v 1.5 2000/12/12 12:44:05 coskrey Exp $ */
 /*
  *
  * Copyright IBM Corporation 1993
@@ -14,7 +13,7 @@
  * software without specific, written prior permission.
  *
  * IBM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
- * ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS, AND 
+ * ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS, AND
  * NONINFRINGEMENT OF THIRD PARTY RIGHTS, IN NO EVENT SHALL
  * IBM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
  * ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
@@ -23,7 +22,6 @@
  * SOFTWARE.
  *
 */
-/* $XFree86: xc/lib/X11/lcFile.c,v 3.32 2003/03/25 04:18:09 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -38,7 +36,7 @@
 
 /************************************************************************/
 
-#ifdef __UNIXOS2__
+#ifndef HAVE_SETEUID
 # define seteuid setuid
 #endif
 #define	iscomment(ch)	((ch) == '#' || (ch) == '\0')
@@ -219,7 +217,7 @@ _XlcParsePath(
 #define XLOCALEDIR "/usr/lib/X11/locale"
 #endif
 
-static void
+void
 xlocaledir(
     char *buf,
     int buf_len)
@@ -266,7 +264,7 @@ xlocaledir(
 		priv = 0;
 	    } else {
 		if (seteuid(oldeuid) == -1) {
-		    /* XXX ouch, coudn't get back to original uid 
+		    /* XXX ouch, coudn't get back to original uid
 		     what can we do ??? */
 		    _exit(127);
 		}
@@ -344,7 +342,7 @@ xlocalelibdir(
 		priv = 0;
 	    } else {
 		if (seteuid(oldeuid) == -1) {
-		    /* XXX ouch, coudn't get back to original uid 
+		    /* XXX ouch, coudn't get back to original uid
 		     what can we do ??? */
 		    _exit(127);
 		}
@@ -425,10 +423,7 @@ resolve_name(
 	    from = args[1], to = args[0];	/* right to left */
 	}
 	if (! strcmp(from, lc_name)) {
-	    name = Xmalloc(strlen(to) + 1);
-	    if (name != NULL) {
-		strcpy(name, to);
-	    }
+	    name = strdup(to);
 	    break;
 	}
     }
@@ -463,11 +458,11 @@ normalize_lcname (const char *name)
 {
     char *p, *ret;
     const char *tmp = name;
-    
+
     p = ret = Xmalloc(strlen(name) + 1);
     if (!p)
 	return NULL;
-    
+
     if (tmp) {
 	while (*tmp && *tmp != '.' && *tmp != '@')
 	    *p++ = *tmp++;
@@ -504,15 +499,17 @@ _XlcFileName(
 
     siname = XLC_PUBLIC(lcd, siname);
 
-    lowercase(cat, category);
+    if (category)
+	lowercase(cat, category);
+    else
+	cat[0] = '\0';
     xlocaledir(dir,XLC_BUFSIZE);
     n = _XlcParsePath(dir, args, NUM_LOCALEDIR);
     for (i = 0; i < n; ++i) {
 	char buf[PATH_MAX], *name;
 
 	name = NULL;
-	if ((5 + (args[i] ? strlen (args[i]) : 0) +
-	    (cat ? strlen (cat) : 0)) < PATH_MAX) {
+	if ((5 + (args[i] ? strlen (args[i]) : 0) + strlen(cat)) < PATH_MAX) {
 	    sprintf(buf, "%s/%s.dir", args[i], cat);
 	    name = resolve_name(siname, buf, RtoL);
 	}
@@ -560,7 +557,7 @@ _XlcResolveLocaleName(
     xlocaledir (dir, PATH_MAX);
     n = _XlcParsePath(dir, args, NUM_LOCALEDIR);
     for (i = 0; i < n; ++i) {
-	if ((2 + (args[i] ? strlen (args[i]) : 0) + 
+	if ((2 + (args[i] ? strlen (args[i]) : 0) +
 	    strlen (locale_alias)) < PATH_MAX) {
 	    sprintf (buf, "%s/%s", args[i], locale_alias);
 	    name = resolve_name (lc_name, buf, LtoR);
@@ -579,8 +576,7 @@ _XlcResolveLocaleName(
 
     if (name == NULL) {
 	/* vendor locale name == Xlocale name, no expansion of alias */
-	pub->siname = Xmalloc (strlen (lc_name) + 1);
-	strcpy (pub->siname, lc_name);
+	pub->siname = strdup (lc_name);
     } else {
 	pub->siname = name;
     }
@@ -592,7 +588,7 @@ _XlcResolveLocaleName(
 	return 1;
     }
 
-    /* 
+    /*
      * pub->siname is in the format <lang>_<terr>.<codeset>, typical would
      * be "en_US.ISO8859-1", "en_US.utf8", "ru_RU.KOI-8", or ja_JP.SJIS,
      * although it could be ja.SJIS too.
@@ -628,9 +624,7 @@ _XlcResolveLocaleName(
 
 /************************************************************************/
 int
-_XlcResolveI18NPath(buf, buf_len)
-    char *buf;
-    int buf_len;
+_XlcResolveI18NPath(char *buf, int buf_len)
 {
     if (buf != NULL) {
 	xlocaledir(buf, buf_len);
@@ -639,10 +633,7 @@ _XlcResolveI18NPath(buf, buf_len)
 }
 
 char *
-_XlcLocaleDirName(dir_name, dir_len, lc_name)
-     char *dir_name;
-     size_t dir_len;
-     char *lc_name;
+_XlcLocaleDirName(char *dir_name, size_t dir_len, char *lc_name)
 {
     char dir[PATH_MAX], buf[PATH_MAX], *name = NULL;
     int i, n;
@@ -664,8 +655,8 @@ _XlcLocaleDirName(dir_name, dir_len, lc_name)
     xlocaledir (dir, PATH_MAX);
     n = _XlcParsePath(dir, args, 256);
     for (i = 0; i < n; ++i) {
-  
-	if ((2 + (args[i] ? strlen(args[i]) : 0) + 
+
+	if ((2 + (args[i] ? strlen(args[i]) : 0) +
  	     strlen(locale_alias)) < PATH_MAX) {
  	    sprintf (buf, "%s/%s", args[i], locale_alias);
  	    name = resolve_name(lc_name, buf, LtoR);
@@ -676,13 +667,13 @@ _XlcLocaleDirName(dir_name, dir_len, lc_name)
 		    name = resolve_name (nlc_name, buf, LtoR);
 	    }
  	}
-  
+
  	/* If name is not an alias, use lc_name for locale.dir search */
  	if (name == NULL)
  	    name = lc_name;
- 
+
  	/* look at locale.dir */
- 
+
  	target_dir = args[i];
  	if (!target_dir) {
  	    /* something wrong */
@@ -690,8 +681,7 @@ _XlcLocaleDirName(dir_name, dir_len, lc_name)
  		Xfree(name);
  	    continue;
  	}
- 	if ((1 + (target_dir ? strlen (target_dir) : 0) +
- 	     strlen("locale.dir")) < PATH_MAX) {
+ 	if ((1 + strlen (target_dir) + strlen("locale.dir")) < PATH_MAX) {
  	    sprintf(buf, "%s/locale.dir", target_dir);
  	    target_name = resolve_name(name, buf, RtoL);
  	}
@@ -722,7 +712,7 @@ _XlcLocaleDirName(dir_name, dir_len, lc_name)
     } else  {
 	strcat(dir_name, "/");
 	strncat(dir_name, target_name, dir_len - strlen(dir_name) - 1);
-	if (strlen(target_name) >= dir_len - strlen(dir_name) - 1) 
+	if (strlen(target_name) >= dir_len - strlen(dir_name) - 1)
 	    dir_name[dir_len - 1] = '\0';
     }
     if (target_name != lc_name)
@@ -735,17 +725,13 @@ _XlcLocaleDirName(dir_name, dir_len, lc_name)
     last_dir_len = strlen (dir_name) + 1;
     last_dir_name = Xmalloc (last_dir_len);
     strcpy (last_dir_name, dir_name);
-    last_lc_name = Xmalloc (strlen (lc_name) + 1);
-    strcpy (last_lc_name, lc_name);
+    last_lc_name = strdup (lc_name);
 
     return dir_name;
 }
 
 char *
-_XlcLocaleLibDirName(dir_name, dir_len, lc_name)
-     char *dir_name;
-     size_t dir_len;
-     char *lc_name;
+_XlcLocaleLibDirName(char *dir_name, size_t dir_len, char *lc_name)
 {
     char dir[PATH_MAX], buf[PATH_MAX], *name = NULL;
     int i, n;
@@ -767,8 +753,8 @@ _XlcLocaleLibDirName(dir_name, dir_len, lc_name)
     xlocalelibdir (dir, PATH_MAX);
     n = _XlcParsePath(dir, args, 256);
     for (i = 0; i < n; ++i) {
-  
-	if ((2 + (args[i] ? strlen(args[i]) : 0) + 
+
+	if ((2 + (args[i] ? strlen(args[i]) : 0) +
  	     strlen(locale_alias)) < PATH_MAX) {
  	    sprintf (buf, "%s/%s", args[i], locale_alias);
  	    name = resolve_name(lc_name, buf, LtoR);
@@ -779,13 +765,13 @@ _XlcLocaleLibDirName(dir_name, dir_len, lc_name)
 		    name = resolve_name (nlc_name, buf, LtoR);
 	    }
  	}
-  
+
  	/* If name is not an alias, use lc_name for locale.dir search */
  	if (name == NULL)
  	    name = lc_name;
- 
+
  	/* look at locale.dir */
- 
+
  	target_dir = args[i];
  	if (!target_dir) {
  	    /* something wrong */
@@ -793,8 +779,7 @@ _XlcLocaleLibDirName(dir_name, dir_len, lc_name)
  		Xfree(name);
  	    continue;
  	}
- 	if ((1 + (target_dir ? strlen (target_dir) : 0) +
- 	     strlen("locale.dir")) < PATH_MAX) {
+ 	if ((1 + strlen (target_dir) + strlen("locale.dir")) < PATH_MAX) {
  	    sprintf(buf, "%s/locale.dir", target_dir);
  	    target_name = resolve_name(name, buf, RtoL);
  	}
@@ -825,7 +810,7 @@ _XlcLocaleLibDirName(dir_name, dir_len, lc_name)
     } else  {
 	strcat(dir_name, "/");
 	strncat(dir_name, target_name, dir_len - strlen(dir_name) - 1);
-	if (strlen(target_name) >= dir_len - strlen(dir_name) - 1) 
+	if (strlen(target_name) >= dir_len - strlen(dir_name) - 1)
 	    dir_name[dir_len - 1] = '\0';
     }
     if (target_name != lc_name)
@@ -838,8 +823,7 @@ _XlcLocaleLibDirName(dir_name, dir_len, lc_name)
     last_dir_len = strlen (dir_name) + 1;
     last_dir_name = Xmalloc (last_dir_len);
     strcpy (last_dir_name, dir_name);
-    last_lc_name = Xmalloc (strlen (lc_name) + 1);
-    strcpy (last_lc_name, lc_name);
+    last_lc_name = strdup (lc_name);
 
     return dir_name;
 }
